import { Injectable } from "@nestjs/common";
import { BaseService } from "../base/base.service";
import { db, ObjectType, Prisma, UserProfile } from "@nice/common";
import { DefaultArgs } from "@prisma/client/runtime/library";
import EventBus, { CrudOperation } from "@server/utils/event-bus";


@Injectable()
export class TrainContentService extends BaseService<Prisma.TrainContentDelegate> {
    constructor() {
        super(db,ObjectType.TRAIN_CONTENT,true);
    }
    async create(args: Prisma.TrainContentCreateArgs) {
        console.log(args)
        const result = await super.create(args)
        this.emitDataChanged(CrudOperation.CREATED,result)
        return result    
    }

    async update(args:Prisma.TrainContentUpdateArgs){
        const result = await super.update(args)
        this.emitDataChanged(CrudOperation.UPDATED,result)
        return result
    }


    async findMany(args: Prisma.TrainContentFindManyArgs) {
        const result = await super.findMany(args);
        return result;
    }


    private emitDataChanged(operation: CrudOperation, data: any) {
        EventBus.emit('dataChanged', {
          type:ObjectType.TRAIN_SITUATION,
          operation,
          data,
        });
    }
}