import React, { useState } from 'react';
import { message, Modal, Button } from 'antd';
import { useStaff } from '@nice/client';
import { defaultFields } from './defaultFields';

type DefaultFieldInitializerProps = {
  fields: any[] | undefined;
  isProcessing: boolean;
  setIsProcessing: (isProcessing: boolean) => void;
  isInitConfirmVisible: boolean;
  setIsInitConfirmVisible: (isVisible: boolean) => void;
};

const checkFieldExists = (fields: any[] | undefined, name: string) => {
  return fields?.some(field => field.name === name);
};

const DefaultFieldInitializer: React.FC<DefaultFieldInitializerProps> = ({
  fields,
  isProcessing,
  setIsProcessing,
  isInitConfirmVisible,
  setIsInitConfirmVisible
}) => {
  const { addCustomField } = useStaff();

  const initializeDefaultFields = async () => {
    try {
      setIsProcessing(true);
      
      // 检查是否已有数据
      if (fields && fields.length > 0) {
        message.warning('数据库中已存在字段数据，请先清空数据后再初始化');
        return;
      }
      // 使用 Promise.all 批量处理
      await Promise.all(
        defaultFields.map(async (field) => {
          try {
            if (!checkFieldExists(fields, field.name)) {
              await addCustomField.mutateAsync(field);
            }
          } catch (error) {
            console.error(`添加字段 ${field.name} 失败:`, error);
          }
        })
      );

      message.success('默认字段初始化成功');
      setIsInitConfirmVisible(false);
    } catch (error) {
      message.error('初始化失败：' + (error instanceof Error ? error.message : '未知错误'));
    } finally {
      setIsProcessing(false);
    }
  };

  return (
    <>
      <Button
        onClick={() => setIsInitConfirmVisible(true)}
        type="default"
        loading={isProcessing}
      >
        初始化默认字段
      </Button>
      <Modal
        title="确认初始化"
        open={isInitConfirmVisible}
        onOk={initializeDefaultFields}
        onCancel={() => setIsInitConfirmVisible(false)}
        confirmLoading={isProcessing}
      >
        <p>初始化将导入所有预设字段，确定要继续吗？</p>
      </Modal>
    </>
  );
};

export default DefaultFieldInitializer;