import React from 'react';
import { Table, Space, Button, Popconfirm, message } from 'antd';
import { EditOutlined, DeleteOutlined } from '@ant-design/icons';
import { FieldTypeOptions } from './defaultFields';

type StaffFieldTableProps = {
  fields: any[] | undefined;
  isLoading: boolean;
  isProcessing: boolean;
  selectedRowKeys: string[];
  setSelectedRowKeys: (keys: string[]) => void;
  handleEdit: (record: any) => void;
  handleDelete: (id: string) => Promise<void>;
  handleBatchDelete: () => Promise<void>;
};

const checkFieldExists = (name: string, excludeId?: string, fields?: any[]) => {
  return fields?.some(field => 
    field.name === name && field.id !== excludeId
  );
};

const StaffFieldTable: React.FC<StaffFieldTableProps> = ({
  fields,
  isLoading,
  isProcessing,
  selectedRowKeys,
  setSelectedRowKeys,
  handleEdit,
  handleDelete,
  handleBatchDelete
}) => {
  console.log(fields);
  const columns = [
    {
      title: '字段名称',
      dataIndex: 'label',
      key: 'label',
    },
    {
      title: '字段标识',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '字段类型',
      dataIndex: 'type',
      key: 'type',
      render: (type: string) => FieldTypeOptions.find(t => t.value === type)?.label,
    },
    {
      title: '字段选项',
      dataIndex: 'options',
      key: 'options',
      render: (options) => {
        const validOptions = Array.isArray(options) ? options : []; 
        return validOptions.map(option => option.label).join(', ');
      },
    },
    {
      title: '必填',
      dataIndex: 'required',
      key: 'required',
      render: (required: boolean) => required ? '是' : '否',
    },
    {
      title: '分组',
      dataIndex: 'group',
      key: 'group',
    },
    {
      title: '操作',
      key: 'action',
      render: (_: any, record: any) => (
        <Space>
          <Button
            type="link"
            icon={<EditOutlined />}
            onClick={() => handleEdit(record)}
          >
            编辑
          </Button>
          <Popconfirm
            title="确定要删除这个字段吗？"
            onConfirm={() => handleDelete(record.id)}
          >
            <Button type="link" danger icon={<DeleteOutlined />}>
              删除
            </Button>
          </Popconfirm>
        </Space>
      ),
    },
  ];

  const rowSelection = {
    selectedRowKeys,
    onChange: (keys: string[]) => {
      setSelectedRowKeys(keys);
    },
  };

  return (
    <>
      <Table
        columns={columns}
        dataSource={fields}
        loading={isLoading || isProcessing}
        rowKey="id"
        rowSelection={rowSelection}
      />
      <Button
        danger
        icon={<DeleteOutlined />}
        onClick={handleBatchDelete}
        loading={isProcessing}
      >
        批量删除
      </Button>
    </>
  );
};

export default StaffFieldTable;